%%
% The following source code is an example (Figure 8) of how 
% to compute the phase function of an individual particle  
% using the theory presented in the article
%
% Jeppe Revall Frisvad. Phase function of a spherical particle
% when scattering an inhomogeneous electromagnetic plane wave.
% Journal of the Optical Society of America A 35(4):669-680.
% April 2018.
%
% Code written by Jeppe Revall Frisvad, 2018.
% Copyright (c) Jeppe Revall Frisvad 2018
%
% Permission is granted to anyone to use this code as 
% software for any purpose, including commercial applications.
% However, the software is provided 'as-is' without any warranty.
%% 
clear;

%input parameters
n_0 = 1;
n_med = complex(1.4, 0.27);  % Rhodamine 6G in methanol 0.4 mol/l [Lu and Penzkofer 1986]
n_p = complex(2.5, 1.4e-7);  % Titanium dioxide particle (refractiveindex.info)
lambda = 530e-9;
r = 0.4e-6;
theta_0 = pi/4;

%transmitted wave vector
n0_sin_theta0 = n_0*sin(theta_0);
k_0 = 2*pi/lambda;
k = k_0*([0 1 0]*n0_sin_theta0 - [0 0 1]*sqrt(n_med*n_med - n0_sin_theta0*n0_sin_theta0));

%in scattering plane
fwd_s = real(k);
fwd_p = real(k/(n_med*n_med));
clen_k = sqrt(k*k.');
alpha_s = acos(fwd_s*k.'/(norm(fwd_s)*clen_k));
alpha_p = acos(fwd_p*k.'/(norm(fwd_p)*clen_k));

%in a plane containing forward direction but perpendicular to scattering plane
n_sca_s = cross(fwd_s, [1 0 0]);
n_sca_p = cross(fwd_p, [1 0 0]);
k_proj_s = k - k*n_sca_s'/(n_sca_s*n_sca_s')*n_sca_s;
k_proj_p = k - k*n_sca_p'/(n_sca_p*n_sca_p')*n_sca_p;
clen_k_proj_s = sqrt(k_proj_s*k_proj_s.');
clen_k_proj_p = sqrt(k_proj_p*k_proj_p.');
alpha_proj_s = acos(k_proj_s*fwd_s'/(norm(fwd_s)*clen_k_proj_s));
alpha_proj_p = acos(k_proj_p*fwd_p'/(norm(fwd_p)*clen_k_proj_p));

%Lorenz-Mie phase function for inhomogeneous waves
theta = linspace(0, 2*pi, 1000);
inh_theta_s = theta - alpha_s;
inh_theta_p = theta - alpha_p;
[S, C_norm] = LorenzMie(theta, r, lambda, n_p, n_med);
[iS_s, iC_norm_s] = inh_LorenzMie(inh_theta_s, r, lambda, n_p, n_med);
[iS_p, iC_norm_p] = inh_LorenzMie(inh_theta_p, r, lambda, n_p, n_med);

%plots
polar(theta, sqr_norm(S(1,:))/C_norm, '-k');
hold on;
polar(theta, sqr_norm(S(2,:))/C_norm, '--k');
%p = (sqr_norm(S(1,:)) + sqr_norm(S(2,:)))/(2*C_norm);
%polar(theta, p);
hold off;
title('Lorenz-Mie phase function');
legend('{\it |S_1|^2} / ({\it |k|^2C_s})', '{\it |S_2|^2} / ({\it |k|^2C_s})');
figure(2);
polar(theta, sqr_norm(iS_s(1,:))/C_norm, '-k');
hold on;
polar(theta, sqr_norm(iS_p(2,:))/C_norm, '--k');
%p = (sqr_norm(iS_s(1,:)) + sqr_norm(iS_p(2,:)))/(2*C_norm);
%polar(theta, p);
hold off;
title('Lorenz-Mie phase function for an inhomogeneous wave');
legend('{\it |S_1|^2} / ({\it |k|^2C_s})', '{\it |S_2|^2} / ({\it |k|^2C_s})');
figure(1);
